@@ -1,18 +1,20 @@
-/* Copyright (c) 1994-1996 David Hogan, see README for licence details */
+/*
+ * Copyright (c) 2014 multiple authors, see README for licence details 
+ */
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include "dat.h"
 #include "fns.h"
 
-Client	*clients;
-Client	*current;
+Client *clients;
+Client *current;
 
 void
-setactive(c, on)
-Client *c;
-int on;
+setactive(Client *c, int on)
 {
 	if (c->parent == c->screen->root) {
 		fprintf(stderr, "9wm: bad parent in setactive; dumping core\n");
@@ -24,28 +26,22 @@ int on;
 		if (c->proto & Ptakefocus)
 			sendcmessage(c->window, wm_protocols, wm_take_focus, 0);
 		cmapfocus(c);
-	}
-	else
-		XGrabButton(dpy, AnyButton, AnyModifier, c->parent, False,
-			ButtonMask, GrabModeAsync, GrabModeSync, None, None);
+	} else
+		XGrabButton(dpy, AnyButton, AnyModifier, c->parent, False, ButtonMask, GrabModeAsync, GrabModeSync, None, None);
 	draw_border(c, on);
 }
 
 void
-draw_border(c, active)
-Client *c;
-int active;
+draw_border(Client *c, int active)
 {
 	XSetWindowBackground(dpy, c->parent, active ? c->screen->black : c->screen->white);
 	XClearWindow(dpy, c->parent);
 	if (c->hold && active)
-		XDrawRectangle(dpy, c->parent, c->screen->gc,
-				INSET, INSET, c->dx+BORDER-INSET, c->dy+BORDER-INSET);
+		XDrawRectangle(dpy, c->parent, c->screen->gc, INSET, INSET, c->dx + BORDER - INSET, c->dy + BORDER - INSET);
 }
 
 void
-active(c)
-Client *c;
+active(Client *c)
 {
 	Client *cc;
 
@@ -75,7 +71,7 @@ Client *c;
 }
 
 void
-nofocus()
+nofocus(void)
 {
 	static Window w = 0;
 	int mask;
@@ -90,22 +86,22 @@ nofocus()
 				return;
 			}
 		cmapnofocus(current->screen);
-		/* if no candidates to revert to, fall through */
+		/*
+		 * if no candidates to revert to, fall through 
+		 */
 	}
 	current = 0;
 	if (w == 0) {
 		mask = CWOverrideRedirect;
 		attr.override_redirect = 1;
-		w = XCreateWindow(dpy, screens[0].root, 0, 0, 1, 1, 0,
-			CopyFromParent, InputOnly, CopyFromParent, mask, &attr);
+		w = XCreateWindow(dpy, screens[0].root, 0, 0, 1, 1, 0, CopyFromParent, InputOnly, CopyFromParent, mask, &attr);
 		XMapWindow(dpy, w);
 	}
 	XSetInputFocus(dpy, w, RevertToPointerRoot, timestamp());
 }
 
 void
-top(c)
-Client *c;
+top(Client *c)
 {
 	Client **l, *cc;
 
@@ -119,13 +115,11 @@ Client *c;
 		}
 		l = &cc->next;
 	}
-	fprintf(stderr, "9wm: %x not on client list in top()\n", c);
+	fprintf(stderr, "9wm: %p not on client list in top()\n", c);
 }
 
 Client *
-getclient(w, create)
-Window w;
-int create;
+getclient(Window w, int create)
 {
 	Client *c;
 
@@ -139,10 +133,12 @@ int create;
 	if (!create)
 		return 0;
 
-	c = (Client *)malloc(sizeof(Client));
+	c = (Client *) malloc(sizeof(Client));
 	memset(c, 0, sizeof(Client));
 	c->window = w;
-	/* c->parent will be set by the caller */
+	/*
+	 * c->parent will be set by the caller 
+	 */
 	c->parent = None;
 	c->reparenting = 0;
 	c->state = WithdrawnState;
@@ -161,8 +157,7 @@ int create;
 }
 
 void
-rmclient(c)
-Client *c;
+rmclient(Client *c)
 {
 	Client *cc;
 
@@ -182,7 +177,7 @@ Client *c;
 	if (c->parent != c->screen->root)
 		XDestroyWindow(dpy, c->parent);
 
-	c->parent = c->window = None;		/* paranoia */
+	c->parent = c->window = None;	/* paranoia */
 	if (current == c) {
 		current = c->revert;
 		if (current == 0)
@@ -194,24 +189,24 @@ Client *c;
 		}
 	}
 	if (c->ncmapwins != 0) {
-		XFree((char *)c->cmapwins);
-		free((char *)c->wmcmaps);
+		XFree((char *) c->cmapwins);
+		free((char *) c->wmcmaps);
 	}
 	if (c->iconname != 0)
-		XFree((char*) c->iconname);
+		XFree((char *) c->iconname);
 	if (c->name != 0)
-		XFree((char*) c->name);
+		XFree((char *) c->name);
 	if (c->instance != 0)
-		XFree((char*) c->instance);
+		XFree((char *) c->instance);
 	if (c->class != 0)
-		XFree((char*) c->class);
-	memset(c, 0, sizeof(Client));		/* paranoia */
+		XFree((char *) c->class);
+	memset(c, 0, sizeof(Client));	/* paranoia */
 	free(c);
 }
 
 #ifdef	DEBUG
 void
-dump_revert()
+dump_revert(void)
 {
 	Client *c;
 	int i;
@@ -230,7 +225,7 @@ dump_revert()
 }
 
 void
-dump_clients()
+dump_clients(void)
 {
 	Client *c;
 
