@@ -1,16 +1,19 @@
-/* Copyright (c) 1994-1996 David Hogan, see README for licence details */
+/*
+ * Copyright (c) 2014 multiple authors, see README for licence details 
+ */
 #include <stdio.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+#include <X11/cursorfont.h>
 #include "dat.h"
 #include "fns.h"
 
 typedef struct {
-	int		width;
-	int		hot[2];
-	unsigned char	mask[64];
-	unsigned char	fore[64];
+	int width;
+	int hot[2];
+	unsigned char mask[64];
+	unsigned char fore[64];
 } Cursordata;
 
 Cursordata sweep0data = {
@@ -129,58 +132,44 @@ Cursordata blitsweep = {
 	 0x02, 0x00, 0x01, 0xfe, 0xff, 0x01, 0x00, 0x00, 0x00}
 };
 
-/*
- *	Grey tile pattern for root background
- */
-
-#define grey_width 4
-#define grey_height 2
-static char grey_bits[] = {
-	0x01, 0x04,
-};
-
-static XColor	bl, wh;
+static XColor bl, wh;
 
 Cursor
-getcursor(c, s)
-Cursordata *c;
-ScreenInfo *s;
+getcursor(Cursordata * c, ScreenInfo * s)
 {
 	Pixmap f, m;
 
-	f = XCreatePixmapFromBitmapData(dpy, s->root, (char *)c->fore,
-		c->width, c->width, 1, 0, 1);
-	m = XCreatePixmapFromBitmapData(dpy, s->root, (char *)c->mask,
-		c->width, c->width, 1, 0, 1);
-	return XCreatePixmapCursor(dpy, f, m, &bl, &wh,
-			c->hot[0], c->hot[1]);
+	f = XCreatePixmapFromBitmapData(dpy, s->root, (char *) c->fore, c->width, c->width, 1, 0, 1);
+	m = XCreatePixmapFromBitmapData(dpy, s->root, (char *) c->mask, c->width, c->width, 1, 0, 1);
+	return XCreatePixmapCursor(dpy, f, m, &bl, &wh, c->hot[0], c->hot[1]);
 }
 
 void
-initcurs(s)
-ScreenInfo *s;
+initcurs(ScreenInfo * s)
 {
 	XColor dummy;
 
-	XAllocNamedColor(dpy, DefaultColormap(dpy, s->num),
-			"black", &bl, &dummy);
-	XAllocNamedColor(dpy, DefaultColormap(dpy, s->num),
-			"white", &wh, &dummy);
+	XAllocNamedColor(dpy, DefaultColormap(dpy, s->num), "black", &bl, &dummy);
+	XAllocNamedColor(dpy, DefaultColormap(dpy, s->num), "white", &wh, &dummy);
 
-	if (nostalgia) {
+	switch (nostalgia) {
+	case BLIT:
 		s->arrow = getcursor(&blitarrow, s);
 		s->target = getcursor(&blittarget, s);
 		s->sweep0 = getcursor(&blitsweep, s);
 		s->boxcurs = getcursor(&blitsweep, s);
-	}
-	else {
+		break;
+	case V1:
 		s->arrow = getcursor(&arrowdata, s);
 		s->target = getcursor(&sightdata, s);
 		s->sweep0 = getcursor(&sweep0data, s);
 		s->boxcurs = getcursor(&boxcursdata, s);
+		break;
+	default:
+		s->arrow = XCreateFontCursor(dpy, XC_left_ptr);
+		s->target = XCreateFontCursor(dpy, XC_crosshair);
+		s->sweep0 = XCreateFontCursor(dpy, XC_sizing);
+		s->boxcurs = XCreateFontCursor(dpy, XC_dotbox);
+		break;
 	}
-
-	s->root_pixmap = XCreatePixmapFromBitmapData(dpy,
-		s->root, grey_bits, grey_width, grey_height,
-		s->black, s->white, DefaultDepth(dpy, s->num));
 }
