@@ -89,6 +89,13 @@ struct ScreenInfo {
 	char			display[256];	/* arbitrary limit */
 };
 
+// Nostalgia options
+enum {
+	MODERN = 0,
+	V1,
+	BLIT
+};
+
 /* main.c */
 extern Display		*dpy;
 extern ScreenInfo	*screens;
@@ -115,6 +122,9 @@ extern Atom 		wm_protocols;
 extern Atom 		wm_delete;
 extern Atom 		wm_take_focus;
 extern Atom 		wm_colormaps;
+extern Atom		utf8_string;
+extern Atom		wm_moveresize;
+extern Atom		active_window;
 
 /* client.c */
 extern Client		*clients;
