@@ -1,5 +1,8 @@
-/* Copyright (c) 1994-1996 David Hogan, see README for licence details */
+/*
+ * Copyright (c) 2014 multiple authors, see README for licence details 
+ */
 #include <stdio.h>
+#include <stdlib.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -7,11 +10,10 @@
 #include "dat.h"
 #include "fns.h"
 
-int 	ignore_badwindow;
+int ignore_badwindow;
 
 void
-fatal(s)
-char *s;
+fatal(char *s)
 {
 	fprintf(stderr, "9wm: ");
 	perror(s);
@@ -20,9 +22,7 @@ char *s;
 }
 
 int
-handler(d, e)
-Display *d;
-XErrorEvent *e;
+handler(Display * d, XErrorEvent * e)
 {
 	char msg[80], req[80], number[80];
 
@@ -40,7 +40,7 @@ XErrorEvent *e;
 	if (req[0] == '\0')
 		sprintf(req, "<request-code-%d>", e->request_code);
 
-	fprintf(stderr, "9wm: %s(0x%x): %s\n", req, e->resourceid, msg);
+	fprintf(stderr, "9wm: %s(0x%x): %s\n", req, (int) e->resourceid, msg);
 
 	if (initting) {
 		fprintf(stderr, "9wm: failure during initialisation; aborting\n");
@@ -50,11 +50,9 @@ XErrorEvent *e;
 }
 
 void
-graberror(f, err)
-char *f;
-int err;
+graberror(char *f, int err)
 {
-#ifdef	DEBUG	/* sick of "bug" reports; grab errors "just happen" */
+#ifdef	DEBUG			/* sick of "bug" reports; grab errors "just happen" */
 	char *s;
 
 	switch (err) {
@@ -87,10 +85,7 @@ int err;
 #ifdef	DEBUG
 
 void
-dotrace(s, c, e)
-char *s;
-Client *c;
-XEvent *e;
+dotrace(char *s, Client * c, XEvent * e)
 {
 	fprintf(stderr, "9wm: %s: c=0x%x", s, c);
 	if (c)
