@@ -6,7 +6,7 @@
 #define	trace(s, c, e)
 #endif
 
-/* main.c */
+/* 9wm.c */
 void	usage();
 void	initscreen();
 ScreenInfo *getscreen();
@@ -46,8 +46,8 @@ int 	_getprop();
 char	*getprop();
 Window	getwprop();
 int 	getiprop();
-int 	getstate();
-void	setstate();
+int 	getwstate();
+void	setwstate();
 void	setlabel();
 void	getproto();
 void	gettrans();
@@ -90,4 +90,4 @@ void	showhints();
 void	dotrace();
 
 /* cursor.c */
-void	initcurs();
+void	initcurs(ScreenInfo * s);
