@@ -1,4 +1,6 @@
-/* Copyright (c) 1994-1996 David Hogan, see README for licence details */
+/*
+ * Copyright (c) 2014 multiple authors, see README for licence details 
+ */
 #include <stdio.h>
 #include <X11/X.h>
 #include <X11/Xos.h>
@@ -8,8 +10,7 @@
 #include "fns.h"
 
 int
-nobuttons(e)	/* Einstuerzende */
-XButtonEvent *e;
+nobuttons(XButtonEvent * e)
 {
 	int state;
 
@@ -18,25 +19,18 @@ XButtonEvent *e;
 }
 
 int
-grab(w, constrain, mask, curs, t)
-Window w;
-Window constrain;
-int mask;
-Cursor curs;
-int t;
+grab(Window w, Window constrain, int mask, Cursor curs, int t)
 {
 	int status;
 
 	if (t == 0)
 		t = timestamp();
-	status = XGrabPointer(dpy, w, False, mask,
-		GrabModeAsync, GrabModeAsync, constrain, curs, t);
+	status = XGrabPointer(dpy, w, False, mask, GrabModeAsync, GrabModeAsync, constrain, curs, t);
 	return status;
 }
 
 void
-ungrab(e)
-XButtonEvent *e;
+ungrab(XButtonEvent * e)
 {
 	XEvent ev;
 
@@ -54,9 +48,7 @@ XButtonEvent *e;
 }
 
 int
-menuhit(e, m)
-XButtonEvent *e;
-Menu *m;
+menuhit(XButtonEvent * e, Menu * m)
 {
 	XEvent ev;
 	int i, n, cur, old, wide, high, status, drawn, warp;
@@ -67,7 +59,7 @@ Menu *m;
 	if (font == 0)
 		return -1;
 	s = getscreen(e->root);
-	if (s == 0 || e->window == s->menuwin)	   /* ugly event mangling */
+	if (s == 0 || e->window == s->menuwin)	/* ugly event mangling */
 		return -1;
 
 	dx = 0;
@@ -82,9 +74,9 @@ Menu *m;
 		cur = n - 1;
 
 	high = font->ascent + font->descent + 1;
-	dy = n*high;
-	x = e->x - wide/2;
-	y = e->y - cur*high - high/2;
+	dy = n * high;
+	x = e->x - wide / 2;
+	y = e->y - cur * high - high / 2;
 	warp = 0;
 	xmax = DisplayWidth(dpy, s->num);
 	ymax = DisplayHeight(dpy, s->num);
@@ -93,9 +85,9 @@ Menu *m;
 		x = 0;
 		warp++;
 	}
-	if (x+wide >= xmax) {
-		e->x -= x+wide-xmax;
-		x = xmax-wide;
+	if (x + wide >= xmax) {
+		e->x -= x + wide - xmax;
+		x = xmax - wide;
 		warp++;
 	}
 	if (y < 0) {
@@ -103,9 +95,9 @@ Menu *m;
 		y = 0;
 		warp++;
 	}
-	if (y+dy >= ymax) {
-		e->y -= y+dy-ymax;
-		y = ymax-dy;
+	if (y + dy >= ymax) {
+		e->y -= y + dy - ymax;
+		y = ymax - dy;
 		warp++;
 	}
 	if (warp)
@@ -115,7 +107,9 @@ Menu *m;
 	XMapRaised(dpy, s->menuwin);
 	status = grab(s->menuwin, None, MenuGrabMask, None, e->time);
 	if (status != GrabSuccess) {
-		/* graberror("menuhit", status); */
+		/*
+		 * graberror("menuhit", status); 
+		 */
 		XUnmapWindow(dpy, s->menuwin);
 		return -1;
 	}
@@ -133,8 +127,8 @@ Menu *m;
 				break;
 			x = ev.xbutton.x;
 			y = ev.xbutton.y;
-			i = y/high;
-			if (cur >= 0 && y >= cur*high-3 && y < (cur+1)*high+3)
+			i = y / high;
+			if (cur >= 0 && y >= cur * high - 3 && y < (cur + 1) * high + 3)
 				i = cur;
 			if (x < 0 || x > wide || y < -3)
 				i = -1;
@@ -153,8 +147,8 @@ Menu *m;
 			x = ev.xbutton.x;
 			y = ev.xbutton.y;
 			old = cur;
-			cur = y/high;
-			if (old >= 0 && y >= old*high-3 && y < (old+1)*high+3)
+			cur = y / high;
+			if (old >= 0 && y >= old * high - 3 && y < (old + 1) * high + 3)
 				cur = old;
 			if (x < 0 || x > wide || y < -3)
 				cur = -1;
@@ -163,29 +157,32 @@ Menu *m;
 			if (cur == old)
 				break;
 			if (old >= 0 && old < n)
-				XFillRectangle(dpy, s->menuwin, s->gc, 0, old*high, wide, high);
+				XFillRectangle(dpy, s->menuwin, s->gc, 0, old * high, wide, high);
 			if (cur >= 0 && cur < n)
-				XFillRectangle(dpy, s->menuwin, s->gc, 0, cur*high, wide, high);
+				XFillRectangle(dpy, s->menuwin, s->gc, 0, cur * high, wide, high);
 			break;
 		case Expose:
 			XClearWindow(dpy, s->menuwin);
 			for (i = 0; i < n; i++) {
-				tx = (wide - XTextWidth(font, m->item[i], strlen(m->item[i])))/2;
-				ty = i*high + font->ascent + 1;
-				XDrawString(dpy, s->menuwin, s->gc, tx, ty, m->item[i], strlen(m->item[i]));
+				char *item = m->item[i];
+
+				if (i < 5) {
+					tx = (wide - XTextWidth(font, item, strlen(item))) / 2;
+				} else {
+					tx = 1;
+				}
+				ty = i * high + font->ascent + 1;
+				XDrawString(dpy, s->menuwin, s->gc, tx, ty, item, strlen(item));
 			}
 			if (cur >= 0 && cur < n)
-				XFillRectangle(dpy, s->menuwin, s->gc, 0, cur*high, wide, high);
+				XFillRectangle(dpy, s->menuwin, s->gc, 0, cur * high, wide, high);
 			drawn = 1;
 		}
 	}
 }
 
 Client *
-selectwin(release, shift, s)
-int release;
-int *shift;
-ScreenInfo *s;
+selectwin(int release, int *shift, ScreenInfo * s)
 {
 	XEvent ev;
 	XButtonEvent *e;
@@ -195,7 +192,7 @@ ScreenInfo *s;
 
 	status = grab(s->root, s->root, ButtonMask, s->target, 0);
 	if (status != GrabSuccess) {
-		graberror("selectwin", status); /* */
+		graberror("selectwin", status);	/* */
 		return 0;
 	}
 	w = None;
@@ -214,7 +211,7 @@ ScreenInfo *s;
 				if (c == 0)
 					ungrab(e);
 				if (shift != 0)
-					*shift = (e->state&ShiftMask) != 0;
+					*shift = (e->state & ShiftMask) != 0;
 				return c;
 			}
 			break;
@@ -223,17 +220,14 @@ ScreenInfo *s;
 			if (e->button != Button3 || e->subwindow != w)
 				return 0;
 			if (shift != 0)
-				*shift = (e->state&ShiftMask) != 0;
+				*shift = (e->state & ShiftMask) != 0;
 			return getclient(w, 0);
 		}
 	}
 }
 
 void
-sweepcalc(c, x, y)
-Client *c;
-int x;
-int y;
+sweepcalc(Client * c, int x, int y)
 {
 	int dx, dy, sx, sy;
 
@@ -249,8 +243,8 @@ int y;
 		sy = -1;
 	}
 
-	dx -= 2*BORDER;
-	dy -= 2*BORDER;
+	dx -= 2 * BORDER;
+	dy -= 2 * BORDER;
 
 	if (!c->is9term) {
 		if (dx < c->min_dx)
@@ -260,8 +254,8 @@ int y;
 	}
 
 	if (c->size.flags & PResizeInc) {
-		dx = c->min_dx + (dx-c->min_dx)/c->size.width_inc*c->size.width_inc;
-		dy = c->min_dy + (dy-c->min_dy)/c->size.height_inc*c->size.height_inc;
+		dx = c->min_dx + (dx - c->min_dx) / c->size.width_inc * c->size.width_inc;
+		dy = c->min_dy + (dy - c->min_dy) / c->size.height_inc * c->size.height_inc;
 	}
 
 	if (c->size.flags & PMaxSize) {
@@ -270,23 +264,19 @@ int y;
 		if (dy > c->size.max_height)
 			dy = c->size.max_height;
 	}
-	c->dx = sx*(dx + 2*BORDER);
-	c->dy = sy*(dy + 2*BORDER);
+	c->dx = sx * (dx + 2 * BORDER);
+	c->dy = sy * (dy + 2 * BORDER);
 }
 
 void
-dragcalc(c, x, y)
-Client *c;
-int x;
-int y;
+dragcalc(Client * c, int x, int y)
 {
 	c->x = x;
 	c->y = y;
 }
 
 void
-drawbound(c)
-Client *c;
+drawbound(Client * c)
 {
 	int x, y, dx, dy;
 	ScreenInfo *s;
@@ -306,26 +296,22 @@ Client *c;
 	}
 	if (dx <= 2 || dy <= 2)
 		return;
-	XDrawRectangle(dpy, s->root, s->gc, x, y, dx-1, dy-1);
-	XDrawRectangle(dpy, s->root, s->gc, x+1, y+1, dx-3, dy-3);
+	XDrawRectangle(dpy, s->root, s->gc, x, y, dx - 1, dy - 1);
+	XDrawRectangle(dpy, s->root, s->gc, x + 1, y + 1, dx - 3, dy - 3);
 }
 
 void
-misleep(msec)
-int msec;
+misleep(int msec)
 {
 	struct timeval t;
 
-	t.tv_sec = msec/1000;
-	t.tv_usec = (msec%1000)*1000;
+	t.tv_sec = msec / 1000;
+	t.tv_usec = (msec % 1000) * 1000;
 	select(0, 0, 0, 0, &t);
 }
 
 int
-sweepdrag(c, e0, recalc)
-Client *c;
-XButtonEvent *e0;
-void (*recalc)();
+sweepdrag(Client * c, XButtonEvent * e0, void (*recalc) ())
 {
 	XEvent ev;
 	int idle;
@@ -339,14 +325,13 @@ void (*recalc)();
 	ody = c->dy;
 	c->x -= BORDER;
 	c->y -= BORDER;
-	c->dx += 2*BORDER;
-	c->dy += 2*BORDER;
+	c->dx += 2 * BORDER;
+	c->dy += 2 * BORDER;
 	if (e0) {
 		c->x = cx = e0->x;
 		c->y = cy = e0->y;
 		recalc(c, e0->x, e0->y);
-	}
-	else
+	} else
 		getmouse(&cx, &cy, c->screen);
 	XGrabServer(dpy);
 	drawbound(c);
@@ -379,8 +364,6 @@ void (*recalc)();
 			drawbound(c);
 			ungrab(e);
 			XUngrabServer(dpy);
-			if (e->button != Button3 && c->init)
-				goto bad;
 			recalc(c, ev.xbutton.x, ev.xbutton.y);
 			if (c->dx < 0) {
 				c->x += c->dx;
@@ -392,14 +375,14 @@ void (*recalc)();
 			}
 			c->x += BORDER;
 			c->y += BORDER;
-			c->dx -= 2*BORDER;
-			c->dy -= 2*BORDER;
+			c->dx -= 2 * BORDER;
+			c->dy -= 2 * BORDER;
 			if (c->dx < 4 || c->dy < 4 || c->dx < c->min_dx || c->dy < c->min_dy)
 				goto bad;
 			return 1;
 		}
 	}
-bad:
+      bad:
 	c->x = ox;
 	c->y = oy;
 	c->dx = odx;
@@ -408,8 +391,7 @@ bad:
 }
 
 int
-sweep(c)
-Client *c;
+sweep(Client * c)
 {
 	XEvent ev;
 	int status;
@@ -419,7 +401,7 @@ Client *c;
 	s = c->screen;
 	status = grab(s->root, s->root, ButtonMask, s->sweep0, 0);
 	if (status != GrabSuccess) {
-		graberror("sweep", status); /* */
+		graberror("sweep", status);	/* */
 		return 0;
 	}
 
@@ -429,40 +411,36 @@ Client *c;
 		ungrab(e);
 		return 0;
 	}
-	if (c->size.flags & (PMinSize|PBaseSize))
-		 setmouse(e->x+c->min_dx, e->y+c->min_dy, s);
+	if (c->size.flags & (PMinSize | PBaseSize))
+		setmouse(e->x + c->min_dx, e->y + c->min_dy, s);
 	XChangeActivePointerGrab(dpy, ButtonMask, s->boxcurs, e->time);
 	return sweepdrag(c, e, sweepcalc);
 }
 
 int
-drag(c)
-Client *c;
+drag(Client * c)
 {
 	int status;
 	ScreenInfo *s;
 
 	s = c->screen;
 	if (c->init)
-		setmouse(c->x-BORDER, c->y-BORDER, s);
+		setmouse(c->x - BORDER, c->y - BORDER, s);
 	else {
-		getmouse(&c->x, &c->y, s);		   /* start at current mouse pos */
+		getmouse(&c->x, &c->y, s);	/* start at current mouse pos */
 		c->x += BORDER;
 		c->y += BORDER;
 	}
 	status = grab(s->root, s->root, ButtonMask, s->boxcurs, 0);
 	if (status != GrabSuccess) {
-		graberror("drag", status); /* */
+		graberror("drag", status);	/* */
 		return 0;
 	}
 	return sweepdrag(c, 0, dragcalc);
 }
 
 void
-getmouse(x, y, s)
-int *x;
-int *y;
-ScreenInfo *s;
+getmouse(int *x, int *y, ScreenInfo * s)
 {
 	Window dw1, dw2;
 	int t1, t2;
@@ -472,10 +450,7 @@ ScreenInfo *s;
 }
 
 void
-setmouse(x, y, s)
-int x;
-int y;
-ScreenInfo *s;
+setmouse(int x, int y, ScreenInfo * s)
 {
 	XWarpPointer(dpy, None, s->root, None, None, None, None, x, y);
 }
