@@ -1,18 +1,23 @@
-/* Copyright (c) 1994-1996 David Hogan, see README for licence details */
+/*
+ * Copyright (c) 2014 multiple authors, see README for licence details 
+ */
 #include <stdio.h>
 #include <signal.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include "dat.h"
 #include "fns.h"
 
-Client	*hiddenc[MAXHIDDEN];
+Client *hiddenc[MAXHIDDEN];
 
-int	numhidden;
+int numhidden;
 
-char	*b3items[B3FIXED+MAXHIDDEN+1] =
-{
+char *b3items[B3FIXED + MAXHIDDEN + 1] = {
 	"New",
 	"Reshape",
 	"Move",
@@ -21,19 +26,16 @@ char	*b3items[B3FIXED+MAXHIDDEN+1] =
 	0,
 };
 
-Menu	b3menu =
-{
+Menu b3menu = {
 	b3items,
 };
 
-Menu	egg =
-{
+Menu egg = {
 	version,
 };
 
 void
-button(e)
-XButtonEvent *e;
+button(XButtonEvent * e)
 {
 	int n, shift;
 	Client *c;
@@ -48,10 +50,8 @@ XButtonEvent *e;
 	if (c) {
 		e->x += c->x - BORDER + 1;
 		e->y += c->y - BORDER + 1;
-	}
-	else if (e->window != e->root)
-		XTranslateCoordinates(dpy, e->window, s->root, e->x, e->y,
-				&e->x, &e->y, &dw);
+	} else if (e->window != e->root)
+		XTranslateCoordinates(dpy, e->window, s->root, e->x, e->y, &e->x, &e->y, &dw);
 	switch (e->button) {
 	case Button1:
 		if (c) {
@@ -61,8 +61,11 @@ XButtonEvent *e;
 		}
 		return;
 	case Button2:
-		if ((e->state&(ShiftMask|ControlMask))==(ShiftMask|ControlMask))
+		if ((e->state & (ShiftMask | ControlMask)) == (ShiftMask | ControlMask)) {
 			menuhit(e, &egg);
+		} else {
+			spawn(s, "mm mouse2");
+		}
 		return;
 	default:
 		return;
@@ -73,27 +76,27 @@ XButtonEvent *e;
 	if (current && current->screen == s)
 		cmapnofocus(s);
 	switch (n = menuhit(e, &b3menu)) {
-	case 0: 	/* New */
-		spawn(s);
+	case 0:		/* New */
+		spawn(s, termprog);
 		break;
-	case 1: 	/* Reshape */
+	case 1:		/* Reshape */
 		reshape(selectwin(1, 0, s));
 		break;
-	case 2: 	/* Move */
+	case 2:		/* Move */
 		move(selectwin(0, 0, s));
 		break;
-	case 3: 	/* Delete */
+	case 3:		/* Delete */
 		shift = 0;
 		c = selectwin(1, &shift, s);
 		delete(c, shift);
 		break;
-	case 4: 	/* Hide */
+	case 4:		/* Hide */
 		hide(selectwin(1, 0, s));
 		break;
-	default:	/* unhide window */
+	default:		/* unhide window */
 		unhide(n - B3FIXED, 1);
 		break;
-	case -1:	/* nothing */
+	case -1:		/* nothing */
 		break;
 	}
 	if (current && current->screen == s)
@@ -101,36 +104,28 @@ XButtonEvent *e;
 }
 
 void
-spawn(s)
-ScreenInfo *s;
+spawn(ScreenInfo * s, char *prog)
 {
-	/*
-	 * ugly dance to avoid leaving zombies.  Could use SIGCHLD,
-	 * but it's not very portable.
-	 */
 	if (fork() == 0) {
-		if (fork() == 0) {
-			close(ConnectionNumber(dpy));
-			if (s->display[0] != '\0')
-				putenv(s->display);
-			if (termprog != NULL) {
-				execl(shell, shell, "-c", termprog, 0);
-				fprintf(stderr, "9wm: exec %s", shell);
-				perror(" failed");
-			}
-			execlp("9term", "9term", "-9wm", 0);
-			execlp("xterm", "xterm", "-ut", 0);
-			perror("9wm: exec 9term/xterm failed");
-			exit(1);
+		close(ConnectionNumber(dpy));
+		if (s->display[0] != '\0') {
+			putenv(s->display);
 		}
-		exit(0);
+		
+		if (prog != NULL) {
+			execl(shell, shell, "-c", prog, NULL);
+			fprintf(stderr, "9wm: exec %s", shell);
+			perror(" failed");
+		}
+		execlp("xterm", "xterm", NULL);
+		perror("9wm: exec xterm failed");
+		exit(1);
 	}
-	wait((int *) 0);
 }
 
 void
 reshape(c)
-Client *c;
+     Client *c;
 {
 	int odx, ody;
 
@@ -143,17 +138,15 @@ Client *c;
 	active(c);
 	top(c);
 	XRaiseWindow(dpy, c->parent);
-	XMoveResizeWindow(dpy, c->parent, c->x-BORDER, c->y-BORDER,
-					c->dx+2*(BORDER-1), c->dy+2*(BORDER-1));
+	XMoveResizeWindow(dpy, c->parent, c->x - BORDER, c->y - BORDER, c->dx + 2 * (BORDER - 1), c->dy + 2 * (BORDER - 1));
 	if (c->dx == odx && c->dy == ody)
 		sendconfig(c);
 	else
-		XMoveResizeWindow(dpy, c->window, BORDER-1, BORDER-1, c->dx, c->dy);
+		XMoveResizeWindow(dpy, c->window, BORDER - 1, BORDER - 1, c->dx, c->dy);
 }
 
 void
-move(c)
-Client *c;
+move(Client *c)
 {
 	if (c == 0)
 		return;
@@ -162,27 +155,28 @@ Client *c;
 	active(c);
 	top(c);
 	XRaiseWindow(dpy, c->parent);
-	XMoveWindow(dpy, c->parent, c->x-BORDER, c->y-BORDER);
+	XMoveWindow(dpy, c->parent, c->x - BORDER, c->y - BORDER);
 	sendconfig(c);
 }
 
 void
 delete(c, shift)
-Client *c;
-int shift;
+     Client *c;
+     int shift;
 {
 	if (c == 0)
 		return;
 	if ((c->proto & Pdelete) && !shift)
 		sendcmessage(c->window, wm_protocols, wm_delete, 0);
 	else
-		XKillClient(dpy, c->window);		/* let event clean up */
+		XKillClient(dpy, c->window);	/* let event clean up */
 }
 
 void
-hide(c)
-Client *c;
+hide(Client * c)
 {
+	int i;
+
 	if (c == 0 || numhidden == MAXHIDDEN)
 		return;
 	if (hidden(c)) {
@@ -191,19 +185,21 @@ Client *c;
 	}
 	XUnmapWindow(dpy, c->parent);
 	XUnmapWindow(dpy, c->window);
-	setstate(c, IconicState);
+	setwstate(c, IconicState);
 	if (c == current)
 		nofocus();
-	hiddenc[numhidden] = c;
-	b3items[B3FIXED+numhidden] = c->label;
+
+	for (i = numhidden; i > 0; i -= 1) {
+		hiddenc[i] = hiddenc[i - 1];
+		b3items[B3FIXED + i] = b3items[B3FIXED + i - 1];
+	}
+	hiddenc[0] = c;
+	b3items[B3FIXED] = c->label;
 	numhidden++;
-	b3items[B3FIXED+numhidden] = 0;
 }
 
 void
-unhide(n, map)
-int n;
-int map;
+unhide(int n, int map)
 {
 	Client *c;
 	int i;
@@ -214,31 +210,30 @@ int map;
 	}
 	c = hiddenc[n];
 	if (!hidden(c)) {
-		fprintf(stderr, "9wm: unhide: not hidden: %s(0x%x)\n",
-			c->label, c->window);
+		fprintf(stderr, "9wm: unhide: not hidden: %s(0x%x)\n", c->label, (int) c->window);
 		return;
 	}
 
 	if (map) {
 		XMapWindow(dpy, c->window);
 		XMapRaised(dpy, c->parent);
-		setstate(c, NormalState);
+		setwstate(c, NormalState);
 		active(c);
 		top(c);
 	}
 
 	numhidden--;
-	for (i = n; i < numhidden; i ++) {
-		hiddenc[i] = hiddenc[i+1];
-		b3items[B3FIXED+i] = b3items[B3FIXED+i+1];
+	for (i = n; i < numhidden; i++) {
+		hiddenc[i] = hiddenc[i + 1];
+		b3items[B3FIXED + i] = b3items[B3FIXED + i + 1];
 	}
-	b3items[B3FIXED+numhidden] = 0;
+	b3items[B3FIXED + numhidden] = 0;
 }
 
 void
 unhidec(c, map)
-Client *c;
-int map;
+     Client *c;
+     int map;
 {
 	int i;
 
@@ -247,14 +242,13 @@ int map;
 			unhide(i, map);
 			return;
 		}
-	fprintf(stderr, "9wm: unhidec: not hidden: %s(0x%x)\n",
-		c->label, c->window);
+	fprintf(stderr, "9wm: unhidec: not hidden: %s(0x%x)\n", c->label, (int) c->window);
 }
 
 void
 renamec(c, name)
-Client *c;
-char *name;
+     Client *c;
+     char *name;
 {
 	int i;
 
@@ -265,7 +259,7 @@ char *name;
 		return;
 	for (i = 0; i < numhidden; i++)
 		if (c == hiddenc[i]) {
-			b3items[B3FIXED+i] = name;
+			b3items[B3FIXED + i] = name;
 			return;
 		}
 }
